summaryrefslogtreecommitdiffstats
path: root/usr/local/www/index.php
diff options
context:
space:
mode:
authorsullrich <sullrich@pfsense.org>2009-12-02 22:07:44 -0500
committersullrich <sullrich@pfsense.org>2009-12-02 22:07:44 -0500
commit3fa86ecd68e92030fbf04c94cebbd1d136881470 (patch)
treeb7f151a365bea3e77d600771e4a536765454aa0b /usr/local/www/index.php
parent0b013ef040e36dd71f6b9ca94aa657d2619309f3 (diff)
downloadpfsense-3fa86ecd68e92030fbf04c94cebbd1d136881470.zip
pfsense-3fa86ecd68e92030fbf04c94cebbd1d136881470.tar.gz
Formatting cleanups. Increase buffer size
Diffstat (limited to 'usr/local/www/index.php')
-rwxr-xr-xusr/local/www/index.php12
1 files changed, 2 insertions, 10 deletions
diff --git a/usr/local/www/index.php b/usr/local/www/index.php
index 1a99763..15e8571 100755
--- a/usr/local/www/index.php
+++ b/usr/local/www/index.php
@@ -45,8 +45,8 @@
// Turn on buffering to speed up rendering
ini_set('output_buffering','true');
- // Start buffering with a cache size of 10094
- ob_start(null, "10094");
+ // Start buffering with a cache size of 100000
+ ob_start(null, "100000");
## Load Essential Includes
require_once('guiconfig.inc');
@@ -76,7 +76,6 @@
if(stristr($swapinfo,'%') == true) $showswap=true;
}
-
## User recently restored his config.
## If packages are installed lets resync
if(file_exists('/conf/needs_package_sync')) {
@@ -91,12 +90,9 @@
}
}
-
## If it is the first time webConfigurator has been
## accessed since initial install show this stuff.
if(file_exists('/conf/trigger_initial_wizard')) {
-
-
echo <<<EOF
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
@@ -504,8 +500,6 @@ echo $jscriptstr;
</div>
</div>
-
-
<input type="hidden" value="" name="sequence" id="sequence">
<img src="./themes/<?= $g['theme']; ?>/images/icons/icon_plus.gif" alt="Click here to add widgets" style="cursor: pointer;" onmouseup="domTT_activate(this, event, 'content', document.getElementById('content1'), 'type', 'velcro', 'delay', 0, 'fade', 'both', 'fadeMax', 100, 'styleClass', 'niceTitle');" />
@@ -688,8 +682,6 @@ echo $jscriptstr;
<div style="clear:both;"></div>
</div>
-
-
<?php include("fend.inc"); ?>
<script type="text/javascript">
OpenPOWER on IntegriCloud